@@ -22,6 +22,7 @@ use crate::{
     },
 };
 
+use crate::jwt::decode_jwt;
 use crate::response::{
     cache_get_response::MomentoGetStatus,
     cache_set_response::{MomentoSetResponse, MomentoSetStatus},
@@ -72,9 +73,15 @@ impl SimpleCacheClientBuilder {
         auth_token: String,
         default_ttl_seconds: NonZeroU64,
     ) -> Result<Self, MomentoError> {
-        let data_endpoint = utils::get_claims(&auth_token).c;
+        let data_endpoint = match decode_jwt(&auth_token) {
+            Ok(claims) => claims.c,
+            Err(e) => return Err(e),
+        };
 
-        let momento_endpoints = MomentoEndpointsResolver::resolve(&auth_token, &None);
+        let momento_endpoints = match MomentoEndpointsResolver::resolve(&auth_token, &None) {
+            Ok(endpoints) => endpoints,
+            Err(e) => return Err(e),
+        };
         let control_endpoint_uri = Uri::try_from(&momento_endpoints.control_endpoint)?;
         let data_endpoint_uri = Uri::try_from(&momento_endpoints.data_endpoint)?;
 
@@ -171,9 +178,16 @@ impl SimpleCacheClient {
         auth_token: String,
         default_ttl_seconds: NonZeroU64,
     ) -> Result<Self, MomentoError> {
-        let data_endpoint = utils::get_claims(&auth_token).c;
+        let data_endpoint = match decode_jwt(&auth_token) {
+            Ok(claims) => claims.c,
+            Err(e) => return Err(e),
+        };
+
         let agent_value = format!("rust:{}", VERSION);
-        let momento_endpoints = MomentoEndpointsResolver::resolve(&auth_token, &None);
+        let momento_endpoints = match MomentoEndpointsResolver::resolve(&auth_token, &None) {
+            Ok(endpoints) => endpoints,
+            Err(e) => return Err(e),
+        };
         let control_client = SimpleCacheClient::build_control_client(
             auth_token.clone(),
             momento_endpoints.control_endpoint,
@@ -219,9 +233,15 @@ impl SimpleCacheClient {
         auth_token: String,
         default_ttl_seconds: NonZeroU64,
     ) -> Result<Self, MomentoError> {
-        let data_endpoint = utils::get_claims(&auth_token).c;
+        let data_endpoint = match decode_jwt(&auth_token) {
+            Ok(claims) => claims.c,
+            Err(e) => return Err(e),
+        };
         let agent_value = format!("momento-cli:{}", VERSION);
-        let momento_endpoints = MomentoEndpointsResolver::resolve(&auth_token, &None);
+        let momento_endpoints = match MomentoEndpointsResolver::resolve(&auth_token, &None) {
+            Ok(endpoints) => endpoints,
+            Err(e) => return Err(e),
+        };
         let control_client = SimpleCacheClient::build_control_client(
             auth_token.clone(),
             momento_endpoints.control_endpoint,
