@@ -1,4 +1,3 @@
-use crate::jwt::{decode_jwt, Claims};
 use crate::response::error::MomentoError;
 use std::num::NonZeroU64;
 
@@ -30,7 +29,3 @@ pub fn is_key_id_valid(key_id: &str) -> Result<(), MomentoError> {
     }
     Ok(())
 }
-
-pub fn get_claims(auth_token: &str) -> Claims {
-    decode_jwt(auth_token).unwrap()
-}
